export const colorLegend = (selection, props) => {
  const { 
    colorScale, 
    circleRadius,
    spacing,
    textOffset,
    onClick,
    selectedColorValue
  } = props;
  
  const backgroundRect = selection.selectAll('rect').data([null]);
  
  backgroundRect.enter().append('rect')
   .merge(backgroundRect)
     .attr('x', -circleRadius * 2)
     .attr('y', -circleRadius * 2 + 350)
     .attr('rx', circleRadius * 2)
     .attr('width', 270)
     .attr('height', spacing * colorScale.domain().length + circleRadius * 2)
     .attr('fill', 'white')
     .attr('opacity', 0.8)
  
  
  const groups = selection.selectAll('.tick')
    .data(colorScale.domain());
  const groupsEnter = groups.enter().append('g').attr('class', 'tick');
  groupsEnter
    .merge(groups)
      .attr('transform', (d, i) =>
        `translate(20, ${i * spacing+350})`
      )
      .attr('opacity', d => 
            (!selectedColorValue || d === selectedColorValue)
            ? 1
            : 0.2)
      .on('click', d => onClick(
  	    d === selectedColorValue
        ? null
        : d
      ));
  groups.exit().remove();
  
  groupsEnter.append('circle')
    .merge(groups.select('circle'))
      .attr('r', circleRadius)
      .attr('fill', colorScale);
  
  groupsEnter.append('text')
    .merge(groups.select('text'))
      .text(d => d)
      .attr('dy', '0.32em')
      .attr('x', textOffset);
}